<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://www.getfoundni.co.uk/
 * @since      1.0.0
 *
 * @package    Notify_Gfni
 * @subpackage Notify_Gfni/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Notify_Gfni
 * @subpackage Notify_Gfni/public
 * @author     Ryan Hull <ryan@getfoundni.co.uk>
 */
class Notify_Gfni_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() { 
		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/notify-gfni-public.css', array(), $this->version, 'all' );
	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() { 
		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/notify-gfni-public.js', array( 'jquery' ), $this->version, false ); 
	}

	public function notify_checkbox($checkout)
	{ 
		if(!get_option( 'notify_settings_option_name' )['key_0']) return;
		woocommerce_form_field( 'notify_signup', array(
			'type'          => 'checkbox',
			'label'         => __('Signup for alerts?'), 
			'checked'		=> true
		), 1); 
	}

	public function notify_checkbox_process()
	{ 
		if ($_POST['notify_signup'] && !empty(get_option( 'notify_settings_option_name' )['key_0'])){ 
			$ch = curl_init('https://notify.getfoundni.co.uk/api/subscribe'); 
			$jsonDataEncoded = json_encode(array(
				'key' 			=> get_option( 'notify_settings_option_name' )['key_0'],
				'email'			=> $_POST['billing_email'],
				'first_name'    => $_POST['billing_first_name'],
            	'last_name'		=> $_POST['billing_last_name']
			)); 
			curl_setopt($ch, CURLOPT_POST, 1); 
			curl_setopt($ch, CURLOPT_POSTFIELDS, $jsonDataEncoded); 
			curl_setopt($ch, CURLOPT_HTTPHEADER, array('Content-Type: application/json'));  
			curl_exec($ch); 
		}  
	}

}
